@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Daniel Mizyrycki (mzdaniel@glidelink.net)
 
 
@@ -33,48 +33,52 @@
     This test can be run in a small test suite with:
 
     $ python tests/runtests.py -C --ssh
-'''
-# Import Python libs
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
-# Import test Libs
+import pytest
 from tests.support.case import SSHCase
+from tests.support.helpers import slowTest
 
 
+@pytest.mark.windows_whitelisted
 class SSHCustomModuleTest(SSHCase):
-    '''
+    """
     Test sls with custom module functionality using ssh
-    '''
+    """
 
+    @slowTest
     def test_ssh_regular_module(self):
-        '''
+        """
         Test regular module work using SSHCase environment
-        '''
-        expected = 'hello'
-        cmd = self.run_function('test.echo', arg=['hello'])
+        """
+        expected = "hello"
+        cmd = self.run_function("test.echo", arg=["hello"])
         self.assertEqual(expected, cmd)
 
+    @slowTest
     def test_ssh_custom_module(self):
-        '''
+        """
         Test custom module work using SSHCase environment
-        '''
-        expected = 'hello'[::-1]
-        cmd = self.run_function('test.recho', arg=['hello'])
+        """
+        expected = "hello"[::-1]
+        cmd = self.run_function("test.recho", arg=["hello"])
         self.assertEqual(expected, cmd)
 
+    @slowTest
     def test_ssh_sls_with_custom_module(self):
-        '''
+        """
         Test sls with custom module work using SSHCase environment
-        '''
+        """
         expected = {
-            "module_|-regular-module_|-test.echo_|-run": 'hello',
-            "module_|-custom-module_|-test.recho_|-run": 'olleh'}
-        cmd = self.run_function('state.sls', arg=['custom_module'])
+            "module_|-regular-module_|-test.echo_|-run": "hello",
+            "module_|-custom-module_|-test.recho_|-run": "olleh",
+        }
+        cmd = self.run_function("state.sls", arg=["custom_module"])
         for key in cmd:
             if not isinstance(cmd, dict) or not isinstance(cmd[key], dict):
-                raise AssertionError('{0} is not a proper state return'
-                                     .format(cmd))
-            elif not cmd[key]['result']:
-                raise AssertionError(cmd[key]['comment'])
-            cmd_ret = cmd[key]['changes'].get('ret', None)
+                raise AssertionError("{0} is not a proper state return".format(cmd))
+            elif not cmd[key]["result"]:
+                raise AssertionError(cmd[key]["comment"])
+            cmd_ret = cmd[key]["changes"].get("ret", None)
             self.assertEqual(cmd_ret, expected[key])
